@@ -3,11 +3,10 @@ context("vizAnnualClimate")
 ## tests
 library(aqp, quietly = TRUE)
 suppressWarnings(library(cluster, quietly = TRUE))
-suppressWarnings(library(dendextend, quietly = TRUE))
-suppressWarnings(library(latticeExtra, quietly = TRUE))
 
 test_that("vizAnnualClimate works as expected", {
-  
+  skip_if_not_installed("dendextend")
+  skip_if_not_installed("latticeExtra")
   # use local data
   data("OSDexamples")
   a <- OSDexamples$climate.annual
